@@ -16,6 +16,7 @@ from albert.core.shared.identifiers import (
     ProjectId,
     TaskId,
     WorkflowId,
+    remove_id_prefix,
 )
 from albert.core.shared.models.base import EntityLink, EntityLinkWithName
 from albert.core.shared.models.patch import PatchOperation
@@ -292,7 +293,7 @@ class TaskCollection(BaseCollection):
             Parameter Group names associated with tasks.
         created_by : list[str], optional
             User names who created the tasks.
-        project_id : str, optional
+        project_id : ProjectId, optional
             ID of the parent project for filtering tasks.
         order_by : OrderBy, optional
             The order in which to return results (asc or desc), default DESCENDING.
@@ -308,6 +309,9 @@ class TaskCollection(BaseCollection):
         Iterator[TaskSearchItem]
             An iterator of matching, lightweight TaskSearchItem entities.
         """
+        if project_id is not None:
+            project_id = remove_id_prefix(project_id, "ProjectId")
+
         params = {
             "offset": offset,
             "order": order_by.value,
@@ -396,7 +400,7 @@ class TaskCollection(BaseCollection):
             Parameter Group names associated with tasks.
         created_by : list[str], optional
             User names who created the tasks.
-        project_id : str, optional
+        project_id : ProjectId, optional
             ID of the parent project for filtering tasks.
         order_by : OrderBy, optional
             The order in which to return results (asc or desc), default DESCENDING.
