@@ -143,12 +143,14 @@ class CustomField(BaseResource):
     min: int | None = Field(default=None)
     max: int | None = Field(default=None)
     entity_categories: list[EntityCategory] | None = Field(default=None, alias="entityCategory")
+    custom_entity_categories: list[str] | None = Field(default=None, alias="customEntityCategory")
     ui_components: list[UIComponent] | None = Field(default=None, alias="ui_components")
     required: bool | None = Field(default=None)
     multiselect: bool | None = Field(default=None)
+    editable: bool | None = Field(default=None)
     pattern: str | None = Field(default=None)
     default: Default | None = Field(default=None)
-    editable: bool | None = Field(default=None)
+    api: dict[str, str] | None = Field(default=None)
 
     @model_validator(mode="after")
     def confirm_field_compatability(self) -> "CustomField":
